@@ -46,12 +46,6 @@
 
 #include <sbkpython.h>
 #include <sbkconverter.h>
-#include <sbkenum.h>
-#include <basewrapper.h>
-#include <bindingmanager.h>
-#include <memory>
-
-#include <pysidesignal.h>
 // Module Includes
 #include <pyside2_qt3drender_python.h>
 #include <pyside2_qt3dcore_python.h>
@@ -66,17 +60,17 @@
 #include <qskyboxentity.h>
 #include <qspritesheet.h>
 #include <qdiffusespecularmaterial.h>
-#include <qplanemesh.h>
-#include <qextrudedtextmesh.h>
 #include <qcylindergeometry.h>
+#include <qextrudedtextmesh.h>
+#include <qplanemesh.h>
 #include <qpervertexcolormaterial.h>
 #include <qgoochmaterial.h>
 #include <qcuboidmesh.h>
 #include <qphongalphamaterial.h>
 #include <qspritegrid.h>
 #include <qorbitcameracontroller.h>
-#include <qtext2dentity.h>
 #include <qconegeometry.h>
+#include <qtext2dentity.h>
 #include <qfirstpersoncameracontroller.h>
 #include <qextrudedtextgeometry.h>
 #include <qconemesh.h>
@@ -89,138 +83,143 @@
 #include <qspheregeometry.h>
 #include <qdiffusespecularmapmaterial.h>
 #include <qcylindermesh.h>
-#include <qdiffusemapmaterial.h>
 #include <qabstractspritesheet.h>
+#include <qdiffusemapmaterial.h>
 #include <qcuboidgeometry.h>
 #include <qtexturematerial.h>
 #include <qspheremesh.h>
 #include <qtorusgeometry.h>
 #include <qmetalroughmaterial.h>
 // Conversion Includes - Primitive Types
-#include <QStringList>
-#include <QString>
-#include <signalmanager.h>
 #include <qabstractitemmodel.h>
+#include <QString>
+#include <QStringList>
+#include <signalmanager.h>
 
 // Conversion Includes - Container Types
-#include <QSet>
-#include <QList>
-#include <QMultiMap>
-#include <QMap>
+#include <pysideqflags.h>
 #include <QLinkedList>
+#include <QList>
+#include <QMap>
+#include <QMultiMap>
+#include <QPair>
+#include <QQueue>
+#include <QSet>
 #include <QStack>
 #include <QVector>
-#include <QQueue>
-#include <QPair>
-#include <pysideqflags.h>
 
 // Type indices
-#define SBK_QT3DEXTRAS_IDX                                           0
-#define SBK_QT3DEXTRAS_QT3DWINDOW_IDX                                38
-#define SBK_QT3DEXTRAS_QSKYBOXENTITY_IDX                             28
-#define SBK_QT3DEXTRAS_QABSTRACTCAMERACONTROLLER_IDX                 1
-#define SBK_QT3DEXTRAS_QFIRSTPERSONCAMERACONTROLLER_IDX              15
-#define SBK_QT3DEXTRAS_QORBITCAMERACONTROLLER_IDX                    22
-#define SBK_QT3DEXTRAS_QABSTRACTCAMERACONTROLLER_INPUTSTATE_IDX      2
-#define SBK_QT3DEXTRAS_QTEXT2DENTITY_IDX                             34
-#define SBK_QT3DEXTRAS_QFORWARDRENDERER_IDX                          16
-#define SBK_QT3DEXTRAS_QEXTRUDEDTEXTMESH_IDX                         14
-#define SBK_QT3DEXTRAS_QSPHEREMESH_IDX                               30
-#define SBK_QT3DEXTRAS_QPLANEMESH_IDX                                27
-#define SBK_QT3DEXTRAS_QCYLINDERMESH_IDX                             9
-#define SBK_QT3DEXTRAS_QCUBOIDMESH_IDX                               7
-#define SBK_QT3DEXTRAS_QCONEMESH_IDX                                 5
-#define SBK_QT3DEXTRAS_QTORUSMESH_IDX                                37
-#define SBK_QT3DEXTRAS_QGOOCHMATERIAL_IDX                            17
-#define SBK_QT3DEXTRAS_QDIFFUSESPECULARMATERIAL_IDX                  12
-#define SBK_QT3DEXTRAS_QDIFFUSESPECULARMAPMATERIAL_IDX               11
-#define SBK_QT3DEXTRAS_QDIFFUSEMAPMATERIAL_IDX                       10
-#define SBK_QT3DEXTRAS_QPHONGMATERIAL_IDX                            25
-#define SBK_QT3DEXTRAS_QPHONGALPHAMATERIAL_IDX                       24
-#define SBK_QT3DEXTRAS_QPERVERTEXCOLORMATERIAL_IDX                   23
-#define SBK_QT3DEXTRAS_QNORMALDIFFUSESPECULARMAPMATERIAL_IDX         21
-#define SBK_QT3DEXTRAS_QNORMALDIFFUSEMAPMATERIAL_IDX                 20
-#define SBK_QT3DEXTRAS_QTEXTUREMATERIAL_IDX                          35
-#define SBK_QT3DEXTRAS_QMORPHPHONGMATERIAL_IDX                       19
-#define SBK_QT3DEXTRAS_QMETALROUGHMATERIAL_IDX                       18
-#define SBK_QT3DEXTRAS_QABSTRACTSPRITESHEET_IDX                      3
-#define SBK_QT3DEXTRAS_QSPRITESHEET_IDX                              32
-#define SBK_QT3DEXTRAS_QSPRITEGRID_IDX                               31
-#define SBK_QT3DEXTRAS_QEXTRUDEDTEXTGEOMETRY_IDX                     13
-#define SBK_QT3DEXTRAS_QSPHEREGEOMETRY_IDX                           29
-#define SBK_QT3DEXTRAS_QPLANEGEOMETRY_IDX                            26
-#define SBK_QT3DEXTRAS_QCYLINDERGEOMETRY_IDX                         8
-#define SBK_QT3DEXTRAS_QCUBOIDGEOMETRY_IDX                           6
-#define SBK_QT3DEXTRAS_QCONEGEOMETRY_IDX                             4
-#define SBK_QT3DEXTRAS_QTORUSGEOMETRY_IDX                            36
-#define SBK_QT3DEXTRAS_QSPRITESHEETITEM_IDX                          33
-#define SBK_Qt3DExtras_IDX_COUNT                                     39
-
+enum : int {
+    SBK_QT3DEXTRAS_IDX                                       = 0,
+    SBK_QT3DEXTRAS_QABSTRACTCAMERACONTROLLER_IDX             = 1,
+    SBK_QT3DEXTRAS_QABSTRACTCAMERACONTROLLER_INPUTSTATE_IDX  = 2,
+    SBK_QT3DEXTRAS_QABSTRACTSPRITESHEET_IDX                  = 3,
+    SBK_QT3DEXTRAS_QCONEGEOMETRY_IDX                         = 4,
+    SBK_QT3DEXTRAS_QCONEMESH_IDX                             = 5,
+    SBK_QT3DEXTRAS_QCUBOIDGEOMETRY_IDX                       = 6,
+    SBK_QT3DEXTRAS_QCUBOIDMESH_IDX                           = 7,
+    SBK_QT3DEXTRAS_QCYLINDERGEOMETRY_IDX                     = 8,
+    SBK_QT3DEXTRAS_QCYLINDERMESH_IDX                         = 9,
+    SBK_QT3DEXTRAS_QDIFFUSEMAPMATERIAL_IDX                   = 10,
+    SBK_QT3DEXTRAS_QDIFFUSESPECULARMAPMATERIAL_IDX           = 11,
+    SBK_QT3DEXTRAS_QDIFFUSESPECULARMATERIAL_IDX              = 12,
+    SBK_QT3DEXTRAS_QEXTRUDEDTEXTGEOMETRY_IDX                 = 13,
+    SBK_QT3DEXTRAS_QEXTRUDEDTEXTMESH_IDX                     = 14,
+    SBK_QT3DEXTRAS_QFIRSTPERSONCAMERACONTROLLER_IDX          = 15,
+    SBK_QT3DEXTRAS_QFORWARDRENDERER_IDX                      = 16,
+    SBK_QT3DEXTRAS_QGOOCHMATERIAL_IDX                        = 17,
+    SBK_QT3DEXTRAS_QMETALROUGHMATERIAL_IDX                   = 18,
+    SBK_QT3DEXTRAS_QMORPHPHONGMATERIAL_IDX                   = 19,
+    SBK_QT3DEXTRAS_QNORMALDIFFUSEMAPMATERIAL_IDX             = 20,
+    SBK_QT3DEXTRAS_QNORMALDIFFUSESPECULARMAPMATERIAL_IDX     = 21,
+    SBK_QT3DEXTRAS_QORBITCAMERACONTROLLER_IDX                = 22,
+    SBK_QT3DEXTRAS_QPERVERTEXCOLORMATERIAL_IDX               = 23,
+    SBK_QT3DEXTRAS_QPHONGALPHAMATERIAL_IDX                   = 24,
+    SBK_QT3DEXTRAS_QPHONGMATERIAL_IDX                        = 25,
+    SBK_QT3DEXTRAS_QPLANEGEOMETRY_IDX                        = 26,
+    SBK_QT3DEXTRAS_QPLANEMESH_IDX                            = 27,
+    SBK_QT3DEXTRAS_QSKYBOXENTITY_IDX                         = 28,
+    SBK_QT3DEXTRAS_QSPHEREGEOMETRY_IDX                       = 29,
+    SBK_QT3DEXTRAS_QSPHEREMESH_IDX                           = 30,
+    SBK_QT3DEXTRAS_QSPRITEGRID_IDX                           = 31,
+    SBK_QT3DEXTRAS_QSPRITESHEET_IDX                          = 32,
+    SBK_QT3DEXTRAS_QSPRITESHEETITEM_IDX                      = 33,
+    SBK_QT3DEXTRAS_QTEXT2DENTITY_IDX                         = 34,
+    SBK_QT3DEXTRAS_QTEXTUREMATERIAL_IDX                      = 35,
+    SBK_QT3DEXTRAS_QTORUSGEOMETRY_IDX                        = 36,
+    SBK_QT3DEXTRAS_QTORUSMESH_IDX                            = 37,
+    SBK_QT3DEXTRAS_QT3DWINDOW_IDX                            = 38,
+    SBK_Qt3DExtras_IDX_COUNT                                 = 39
+};
 // This variable stores all Python types exported by this module.
 extern PyTypeObject** SbkPySide2_Qt3DExtrasTypes;
 
+// This variable stores the Python module object exported by this module.
+extern PyObject* SbkPySide2_Qt3DExtrasModuleObject;
+
 // This variable stores all type converters exported by this module.
 extern SbkConverter** SbkPySide2_Qt3DExtrasTypeConverters;
 
 // Converter indices
-#define SBK_QT3DEXTRAS_QVECTOR_QT3DCORE_QNODEPTR_IDX                 0 // QVector<Qt3DCore::QNode* >
-#define SBK_QT3DEXTRAS_QLIST_QOBJECTPTR_IDX                          1 // const QList<QObject* > &
-#define SBK_QT3DEXTRAS_QLIST_QBYTEARRAY_IDX                          2 // QList<QByteArray >
-#define SBK_QT3DEXTRAS_QVECTOR_QT3DCORE_QENTITYPTR_IDX               3 // QVector<Qt3DCore::QEntity* >
-#define SBK_QT3DEXTRAS_QVECTOR_QT3DRENDER_QATTRIBUTEPTR_IDX          4 // QVector<Qt3DRender::QAttribute* >
-#define SBK_QT3DEXTRAS_QVECTOR_QT3DRENDER_QPARAMETERPTR_IDX          5 // QVector<Qt3DRender::QParameter* >
-#define SBK_QT3DEXTRAS_QVECTOR_QT3DCORE_QCOMPONENTPTR_IDX            6 // QVector<Qt3DCore::QComponent* >
-#define SBK_QT3DEXTRAS_QVECTOR_QT3DRENDER_QFILTERKEYPTR_IDX          7 // QVector<Qt3DRender::QFilterKey* >
-#define SBK_QT3DEXTRAS_QVECTOR_QT3DEXTRAS_QSPRITESHEETITEMPTR_IDX    8 // QVector<Qt3DExtras::QSpriteSheetItem* >
-#define SBK_QT3DEXTRAS_QLIST_QVARIANT_IDX                            9 // QList<QVariant >
-#define SBK_QT3DEXTRAS_QLIST_QSTRING_IDX                             10 // QList<QString >
-#define SBK_QT3DEXTRAS_QMAP_QSTRING_QVARIANT_IDX                     11 // QMap<QString,QVariant >
-#define SBK_Qt3DExtras_CONVERTERS_IDX_COUNT                          12
-
+enum : int {
+    SBK_QT3DEXTRAS_QVECTOR_QT3DCORE_QNODEPTR_IDX             = 0, // QVector<Qt3DCore::QNode* >
+    SBK_QT3DEXTRAS_QLIST_QOBJECTPTR_IDX                      = 1, // const QList<QObject* > &
+    SBK_QT3DEXTRAS_QVECTOR_QT3DCORE_QCOMPONENTPTR_IDX        = 2, // QVector<Qt3DCore::QComponent* >
+    SBK_QT3DEXTRAS_QLIST_QBYTEARRAY_IDX                      = 3, // QList<QByteArray >
+    SBK_QT3DEXTRAS_QVECTOR_QT3DRENDER_QATTRIBUTEPTR_IDX      = 4, // QVector<Qt3DRender::QAttribute* >
+    SBK_QT3DEXTRAS_QVECTOR_QT3DCORE_QENTITYPTR_IDX           = 5, // QVector<Qt3DCore::QEntity* >
+    SBK_QT3DEXTRAS_QVECTOR_QT3DRENDER_QPARAMETERPTR_IDX      = 6, // QVector<Qt3DRender::QParameter* >
+    SBK_QT3DEXTRAS_QVECTOR_QT3DRENDER_QFILTERKEYPTR_IDX      = 7, // QVector<Qt3DRender::QFilterKey* >
+    SBK_QT3DEXTRAS_QVECTOR_QT3DEXTRAS_QSPRITESHEETITEMPTR_IDX = 8, // QVector<Qt3DExtras::QSpriteSheetItem* >
+    SBK_QT3DEXTRAS_QLIST_QVARIANT_IDX                        = 9, // QList<QVariant >
+    SBK_QT3DEXTRAS_QLIST_QSTRING_IDX                         = 10, // QList<QString >
+    SBK_QT3DEXTRAS_QMAP_QSTRING_QVARIANT_IDX                 = 11, // QMap<QString,QVariant >
+    SBK_Qt3DExtras_CONVERTERS_IDX_COUNT                      = 12
+};
 // Macros for type check
 
 namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::Qt3DWindow >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QT3DWINDOW_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QSkyboxEntity >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QSKYBOXENTITY_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QAbstractCameraController >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QABSTRACTCAMERACONTROLLER_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QFirstPersonCameraController >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QFIRSTPERSONCAMERACONTROLLER_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QOrbitCameraController >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QORBITCAMERACONTROLLER_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QAbstractCameraController::InputState >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QABSTRACTCAMERACONTROLLER_INPUTSTATE_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QText2DEntity >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QTEXT2DENTITY_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QForwardRenderer >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QFORWARDRENDERER_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QExtrudedTextMesh >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QEXTRUDEDTEXTMESH_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QSphereMesh >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QSPHEREMESH_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QPlaneMesh >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QPLANEMESH_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QCylinderMesh >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QCYLINDERMESH_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QCuboidMesh >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QCUBOIDMESH_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QConeMesh >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QCONEMESH_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QTorusMesh >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QTORUSMESH_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QGoochMaterial >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QGOOCHMATERIAL_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QDiffuseSpecularMaterial >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QDIFFUSESPECULARMATERIAL_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QDiffuseSpecularMapMaterial >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QDIFFUSESPECULARMAPMATERIAL_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QDiffuseMapMaterial >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QDIFFUSEMAPMATERIAL_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QPhongMaterial >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QPHONGMATERIAL_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QPhongAlphaMaterial >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QPHONGALPHAMATERIAL_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QPerVertexColorMaterial >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QPERVERTEXCOLORMATERIAL_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QNormalDiffuseSpecularMapMaterial >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QNORMALDIFFUSESPECULARMAPMATERIAL_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QNormalDiffuseMapMaterial >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QNORMALDIFFUSEMAPMATERIAL_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QTextureMaterial >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QTEXTUREMATERIAL_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QMorphPhongMaterial >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QMORPHPHONGMATERIAL_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QMetalRoughMaterial >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QMETALROUGHMATERIAL_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QAbstractSpriteSheet >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QABSTRACTSPRITESHEET_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QSpriteSheet >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QSPRITESHEET_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QSpriteGrid >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QSPRITEGRID_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QExtrudedTextGeometry >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QEXTRUDEDTEXTGEOMETRY_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QSphereGeometry >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QSPHEREGEOMETRY_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QPlaneGeometry >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QPLANEGEOMETRY_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QCylinderGeometry >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QCYLINDERGEOMETRY_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QCuboidGeometry >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QCUBOIDGEOMETRY_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QConeGeometry >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QCONEGEOMETRY_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QTorusGeometry >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QTORUSGEOMETRY_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QConeMesh >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QCONEMESH_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QCuboidGeometry >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QCUBOIDGEOMETRY_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QCuboidMesh >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QCUBOIDMESH_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QCylinderGeometry >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QCYLINDERGEOMETRY_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QCylinderMesh >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QCYLINDERMESH_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QDiffuseMapMaterial >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QDIFFUSEMAPMATERIAL_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QDiffuseSpecularMapMaterial >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QDIFFUSESPECULARMAPMATERIAL_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QDiffuseSpecularMaterial >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QDIFFUSESPECULARMATERIAL_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QExtrudedTextGeometry >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QEXTRUDEDTEXTGEOMETRY_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QExtrudedTextMesh >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QEXTRUDEDTEXTMESH_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QFirstPersonCameraController >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QFIRSTPERSONCAMERACONTROLLER_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QForwardRenderer >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QFORWARDRENDERER_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QGoochMaterial >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QGOOCHMATERIAL_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QMetalRoughMaterial >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QMETALROUGHMATERIAL_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QMorphPhongMaterial >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QMORPHPHONGMATERIAL_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QNormalDiffuseMapMaterial >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QNORMALDIFFUSEMAPMATERIAL_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QNormalDiffuseSpecularMapMaterial >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QNORMALDIFFUSESPECULARMAPMATERIAL_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QOrbitCameraController >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QORBITCAMERACONTROLLER_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QPerVertexColorMaterial >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QPERVERTEXCOLORMATERIAL_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QPhongAlphaMaterial >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QPHONGALPHAMATERIAL_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QPhongMaterial >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QPHONGMATERIAL_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QPlaneGeometry >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QPLANEGEOMETRY_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QPlaneMesh >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QPLANEMESH_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QSkyboxEntity >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QSKYBOXENTITY_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QSphereGeometry >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QSPHEREGEOMETRY_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QSphereMesh >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QSPHEREMESH_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QSpriteGrid >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QSPRITEGRID_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QSpriteSheet >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QSPRITESHEET_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QSpriteSheetItem >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QSPRITESHEETITEM_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QText2DEntity >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QTEXT2DENTITY_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QTextureMaterial >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QTEXTUREMATERIAL_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QTorusGeometry >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QTORUSGEOMETRY_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::QTorusMesh >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QTORUSMESH_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DExtras::Qt3DWindow >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QT3DWINDOW_IDX]); }
 
 } // namespace Shiboken
 
