@@ -46,12 +46,6 @@
 
 #include <sbkpython.h>
 #include <sbkconverter.h>
-#include <sbkenum.h>
-#include <basewrapper.h>
-#include <bindingmanager.h>
-#include <memory>
-
-#include <pysidesignal.h>
 // Module Includes
 #include <pyside2_qtcore_python.h>
 
@@ -62,40 +56,45 @@
 // Conversion Includes - Primitive Types
 #include <qabstractitemmodel.h>
 #include <QString>
-#include <signalmanager.h>
 #include <QStringList>
+#include <signalmanager.h>
 
 // Conversion Includes - Container Types
-#include <QStack>
+#include <pysideqflags.h>
+#include <QLinkedList>
 #include <QList>
 #include <QMap>
-#include <pysideqflags.h>
+#include <QMultiMap>
 #include <QPair>
 #include <QQueue>
-#include <QMultiMap>
 #include <QSet>
-#include <QLinkedList>
+#include <QStack>
 #include <QVector>
 
 // Type indices
-#define SBK_QTCONCURRENT_IDX                                         1
-#define SBK_QTCONCURRENT_THREADFUNCTIONRESULT_IDX                    3
-#define SBK_QTCONCURRENT_REDUCEOPTION_IDX                            2
-#define SBK_QFLAGS_QTCONCURRENT_REDUCEOPTION__IDX                    0
-#define SBK_QtConcurrent_IDX_COUNT                                   4
-
+enum : int {
+    SBK_QTCONCURRENT_IDX                                     = 1,
+    SBK_QTCONCURRENT_THREADFUNCTIONRESULT_IDX                = 3,
+    SBK_QTCONCURRENT_REDUCEOPTION_IDX                        = 2,
+    SBK_QFLAGS_QTCONCURRENT_REDUCEOPTION_IDX                 = 0,
+    SBK_QtConcurrent_IDX_COUNT                               = 4
+};
 // This variable stores all Python types exported by this module.
 extern PyTypeObject** SbkPySide2_QtConcurrentTypes;
 
+// This variable stores the Python module object exported by this module.
+extern PyObject* SbkPySide2_QtConcurrentModuleObject;
+
 // This variable stores all type converters exported by this module.
 extern SbkConverter** SbkPySide2_QtConcurrentTypeConverters;
 
 // Converter indices
-#define SBK_QTCONCURRENT_QLIST_QVARIANT_IDX                          0 // QList<QVariant >
-#define SBK_QTCONCURRENT_QLIST_QSTRING_IDX                           1 // QList<QString >
-#define SBK_QTCONCURRENT_QMAP_QSTRING_QVARIANT_IDX                   2 // QMap<QString,QVariant >
-#define SBK_QtConcurrent_CONVERTERS_IDX_COUNT                        3
-
+enum : int {
+    SBK_QTCONCURRENT_QLIST_QVARIANT_IDX                      = 0, // QList<QVariant >
+    SBK_QTCONCURRENT_QLIST_QSTRING_IDX                       = 1, // QList<QString >
+    SBK_QTCONCURRENT_QMAP_QSTRING_QVARIANT_IDX               = 2, // QMap<QString,QVariant >
+    SBK_QtConcurrent_CONVERTERS_IDX_COUNT                    = 3
+};
 // Macros for type check
 
 namespace Shiboken
@@ -104,7 +103,7 @@ namespace Shiboken
 // PyType functions, to get the PyObjectType for a type T
 template<> inline PyTypeObject* SbkType< ::QtConcurrent::ThreadFunctionResult >() { return SbkPySide2_QtConcurrentTypes[SBK_QTCONCURRENT_THREADFUNCTIONRESULT_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QtConcurrent::ReduceOption >() { return SbkPySide2_QtConcurrentTypes[SBK_QTCONCURRENT_REDUCEOPTION_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QFlags<QtConcurrent::ReduceOption> >() { return SbkPySide2_QtConcurrentTypes[SBK_QFLAGS_QTCONCURRENT_REDUCEOPTION__IDX]; }
+template<> inline PyTypeObject* SbkType< ::QFlags<QtConcurrent::ReduceOption> >() { return SbkPySide2_QtConcurrentTypes[SBK_QFLAGS_QTCONCURRENT_REDUCEOPTION_IDX]; }
 
 } // namespace Shiboken
 
